<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

class Action_captcha extends \Ciext\Controller\AbstractJsonController
{

    public function renew()
    {
        $this->load->model('callme/captcha_tmodel');
        $captcha = $this->captcha_tmodel->new_captcha();

        return $this->response(['image' => $captcha['image']]);
    }

}
