<?php

return [
    'project_modules' => [
        'pages' => [
            'callme_module' => [
                'label' => 'Обратная связь',
                'position' => 40,
                'acl_resource' => 'callme',
                'acl_action' => 'manager',
                'file' => __DIR__ . '/../docs/callme.md',
                'uri' => 'callme/manager',
                'pages' => [
                    'callme_add_edit' => [
                        'label' => 'Изменение сообщения в форме Обратная связь',
                        'position' => 10,
                        'file' => __DIR__ . '/../docs/callme_add_edit.md',
                        'uri' => 'callme/manager/edit',
                    ],
                ],
            ],
        ],
    ],
];
